# !/usr/bin/env python

from setuptools import setup

setup(
    name='bulv1ne-django-utils',
    packages=['utils'],
    version='0.0.2',
    description='Django utils for all kinds of situations',
    author='Niels Lemmens',
    license='MIT',
    author_email='draso.odin@gmail.com',
    url='https://github.com/bulv1ne/django-utils',
    keywords=['django', 'utils'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Software Development',
        'Topic :: Utilities',
    ],
)
